@@ -1,5 +1,3 @@
-context("test-expectation")
-
 test_that("expectation contains failure message even when successful", {
   e <- expect(TRUE, "I failed")
   expect_equal(e$message, "I failed")
@@ -26,3 +24,19 @@ test_that("`expect()` and `exp_signal()` signal expectations", {
   expect_error(exp_signal(new_expectation("success", "")), regexp = NA)
   expect_error(exp_signal(new_expectation("failure", "")), class = "expectation_failure")
 })
+
+test_that("conditionMessage() is called during conversion", {
+  local_bindings(
+    conditionMessage.foobar = function(...) "dispatched",
+    .env = global_env()
+  )
+
+  wrn <- warning_cnd("foobar", message = "wrong")
+  expect_identical(as.expectation(wrn)$message, "dispatched")
+
+  err <- error_cnd("foobar", message = "wrong")
+  expect_identical(as.expectation(err)$message, "dispatched")
+
+  err <- cnd(c("foobar", "skip"), message = "wrong")
+  expect_identical(as.expectation(err)$message, "dispatched")
+})
